sol.models.mergedplayer -- Merged players — SoL 4 developers documentation

# `sol.models.mergedplayer` -- Merged players

class `sol.models.mergedplayer.` `MergedPlayer`(**kwargs)

  A player who has been merged into another.

  `caption`(html=None, localized=True)

    Description of the player, made up concatenating his names.

  property `description`

    Description of the player, made up concatenating his names.

  `firstname`

    Player's first name.

  `idmergedplayer`

    Primary key.

  `idplayer`

    Target `player`'s ID.

  `lastname`

    Player's last name.

  `nickname`

    Player's nickname, used also for login purposes.